@@ -21,6 +21,8 @@
 #include <QScroller>
 #include <QTimer>
 
+#include <set>
+
 class KFilePlacesView;
 class QTimeLine;
 
@@ -50,6 +52,7 @@ public:
     void addDisappearingItem(const QModelIndex &index);
     void addDisappearingItemGroup(const QModelIndex &index);
     void setDisappearingItemProgress(qreal value);
+    void setDeviceBusyAnimationRotation(qreal angle);
 
     void setShowHoverIndication(bool show);
     void setHoveredHeaderArea(const QModelIndex &index);
@@ -96,6 +99,8 @@ private:
     qreal m_disappearingHeightScale;
     qreal m_disappearingOpacity;
 
+    qreal m_busyAnimationRotation = 0.0;
+
     bool m_showHoverIndication;
     QPersistentModelIndex m_hoveredHeaderArea;
     QPersistentModelIndex m_hoveredAction;
@@ -106,6 +111,9 @@ private:
 
     mutable QTimer m_pollFreeSpace;
     mutable QMap<QPersistentModelIndex, PlaceFreeSpaceInfo> m_freeSpaceInfo;
+
+    mutable std::set<QPersistentModelIndex> m_elidedTexts;
+
     // constructing KColorScheme is expensive, cache the negative color
     mutable QColor m_warningCapacityBarColor;
 };
@@ -128,12 +136,12 @@ public:
         m_rubberBand = new QRubberBand(QRubberBand::Rectangle, parent);
     }
 
-    const QModelIndex &hoveredHeaderAreaIndex() const
+    const QModelIndex hoveredHeaderAreaIndex()
     {
         return m_hoveredHeaderAreaIndex;
     }
 
-    const QModelIndex &hoveredActionIndex() const
+    const QModelIndex hoveredActionIndex()
     {
         return m_hoveredActionIndex;
     }
@@ -345,13 +353,14 @@ protected:
             m_scroller->stop();
 
             // simulate a mousePressEvent, to allow KFilePlacesView to select the items
-            const QPoint tapViewportPos(q->viewport()->mapFromGlobal(tap->position().toPoint()));
-            QMouseEvent fakeMousePress(QEvent::MouseButtonPress, tapViewportPos, Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
+            const QPointF tapGlobalPos = tap->position(); // QTapAndHoldGesture::position is global
+            const QPointF tapViewportPos(q->viewport()->mapFromGlobal(tapGlobalPos));
+            QMouseEvent fakeMousePress(QEvent::MouseButtonPress, tapViewportPos, tapGlobalPos, Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
             onPressed(&fakeMousePress);
             q->mousePressEvent(&fakeMousePress);
 
             const QPoint tapIndicatorSize(80, 80);
-            const QPoint pos(q->mapFromGlobal(tap->position().toPoint()));
+            const QPoint pos(q->mapFromGlobal(tapGlobalPos.toPoint()));
             const QRect tapIndicatorRect(pos - (tapIndicatorSize / 2), pos + (tapIndicatorSize / 2));
             m_rubberBand->setGeometry(tapIndicatorRect.normalized());
             m_rubberBand->show();
@@ -386,8 +395,11 @@ protected:
                 m_rubberBand->hide();
             }
             // simulate a mousePressEvent, to allow KFilePlacesView to select the items
+            const QPointF tapPosition = tap->position(); // QTapGesture::position is local
+            const QPointF globalTapPosition = q->mapToGlobal(tapPosition);
             QMouseEvent fakeMousePress(QEvent::MouseButtonPress,
-                                       tap->position(),
+                                       tapPosition,
+                                       globalTapPosition,
                                        m_tapAndHoldActive ? Qt::RightButton : Qt::LeftButton,
                                        m_tapAndHoldActive ? Qt::RightButton : Qt::LeftButton,
                                        Qt::NoModifier);
@@ -396,7 +408,7 @@ protected:
 
             if (m_tapAndHoldActive) {
                 // simulate a contextMenuEvent
-                QContextMenuEvent fakeContextMenu(QContextMenuEvent::Mouse, tap->position().toPoint(), q->mapToGlobal(tap->position().toPoint()));
+                QContextMenuEvent fakeContextMenu(QContextMenuEvent::Mouse, tapPosition.toPoint(), globalTapPosition.toPoint());
                 q->contextMenuEvent(&fakeContextMenu);
             }
             m_tapAndHoldActive = false;
