@@ -60,9 +60,7 @@ class KFileItemListProperties;
  * The desktop file contents must also be compiled into the plugin as JSON data.
  * The following CMake code builds and installs the plugin:
  * \code
- * set(myactionplugin_SRCS myactionplugin.cpp)
- *
- * kcoreaddons_add_plugin(myactionplugin SOURCES ${myactionplugin_SRCS} INSTALL_NAMESPACE "kf5/kfileitemaction")
+ * kcoreaddons_add_plugin(myactionplugin SOURCES myactionplugin.cpp INSTALL_NAMESPACE "kf5/kfileitemaction")
  * kcoreaddons_desktop_to_json(myactionplugin myactionplugin.desktop) # generate the json file
  *
  * target_link_libraries(myactionplugin KF5::KIOWidgets)
@@ -81,24 +79,27 @@ class KIOWIDGETS_EXPORT KAbstractFileItemActionPlugin : public QObject
     Q_OBJECT
 
 public:
-    KAbstractFileItemActionPlugin(QObject *parent);
+    explicit KAbstractFileItemActionPlugin(QObject *parent);
 
-    virtual ~KAbstractFileItemActionPlugin();
+    ~KAbstractFileItemActionPlugin() override;
 
     /**
      * Implement the actions method in the plugin in order to create actions.
      *
-     * The returned actions should have the KAbstractFileItemActionPlugin object
-     * as their parent.
-     *
      * @param fileItemInfos  Information about the selected file items.
-     * @param parentWidget   To be used as parent for the returned QActions and error messages or the like.
+     * @param parentWidget   To be used as parent for the returned QActions
      *
      * @return A list of actions to be added to a contextual menu for the file
      *         items.
      */
-    virtual QList<QAction *> actions(const KFileItemListProperties &fileItemInfos,
-                                     QWidget *parentWidget) = 0;
+    virtual QList<QAction *> actions(const KFileItemListProperties &fileItemInfos, QWidget *parentWidget) = 0;
+
+Q_SIGNALS:
+    /**
+     * Emits an error which will be displayed to the user
+     * @since 5.82
+     */
+    void error(const QString &errorMessage);
 };
 
 #endif
